@@ -13,7 +13,7 @@ import aws_cdk.aws_ec2
 import aws_cdk.aws_logs
 import aws_cdk.cdk
 import aws_cdk.cx_api
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53", "0.29.0", __name__, "aws-route53@0.29.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53", "0.31.0", __name__, "aws-route53@0.31.0.jsii.tgz")
 class AliasRecord(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53.AliasRecord"):
     """A Route53 alias record."""
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, record_name: str, target: "IAliasRecordTarget", zone: "IHostedZone") -> None:
@@ -1027,8 +1027,8 @@ class CommonHostedZoneProps(_CommonHostedZoneProps):
     name, specify a fully qualified domain name.
     """
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-route53.HostedZoneImportProps", jsii_struct_bases=[])
-class HostedZoneImportProps(jsii.compat.TypedDict):
+@jsii.data_type(jsii_type="@aws-cdk/aws-route53.HostedZoneAttributes", jsii_struct_bases=[])
+class HostedZoneAttributes(jsii.compat.TypedDict):
     """Reference to a hosted zone."""
     hostedZoneId: str
     """Identifier of the hosted zone."""
@@ -1083,7 +1083,7 @@ class HostedZoneProvider(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route5
         return jsii.invoke(self, "findAndImport", [scope, id])
 
     @jsii.member(jsii_name="findHostedZone")
-    def find_hosted_zone(self) -> "HostedZoneImportProps":
+    def find_hosted_zone(self) -> "HostedZoneAttributes":
         """Return the hosted zone meeting the filter."""
         return jsii.invoke(self, "findHostedZone", [])
 
@@ -1133,7 +1133,11 @@ class IHostedZone(aws_cdk.cdk.IResource, jsii.compat.Protocol):
     @property
     @jsii.member(jsii_name="hostedZoneId")
     def hosted_zone_id(self) -> str:
-        """ID of this hosted zone, such as "Z23ABC4XYZL05B"."""
+        """ID of this hosted zone, such as "Z23ABC4XYZL05B".
+
+        attribute:
+            true
+        """
         ...
 
     @property
@@ -1148,11 +1152,14 @@ class IHostedZone(aws_cdk.cdk.IResource, jsii.compat.Protocol):
         """Returns the set of name servers for the specific hosted zone. For example: ns1.example.com.
 
         This attribute will be undefined for private hosted zones or hosted zones imported from another stack.
+
+        attribute:
+            true
         """
         ...
 
     @jsii.member(jsii_name="export")
-    def export(self) -> "HostedZoneImportProps":
+    def export(self) -> "HostedZoneAttributes":
         """Export the hosted zone."""
         ...
 
@@ -1163,7 +1170,11 @@ class _IHostedZoneProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
     @property
     @jsii.member(jsii_name="hostedZoneId")
     def hosted_zone_id(self) -> str:
-        """ID of this hosted zone, such as "Z23ABC4XYZL05B"."""
+        """ID of this hosted zone, such as "Z23ABC4XYZL05B".
+
+        attribute:
+            true
+        """
         return jsii.get(self, "hostedZoneId")
 
     @property
@@ -1178,11 +1189,14 @@ class _IHostedZoneProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
         """Returns the set of name servers for the specific hosted zone. For example: ns1.example.com.
 
         This attribute will be undefined for private hosted zones or hosted zones imported from another stack.
+
+        attribute:
+            true
         """
         return jsii.get(self, "hostedZoneNameServers")
 
     @jsii.member(jsii_name="export")
-    def export(self) -> "HostedZoneImportProps":
+    def export(self) -> "HostedZoneAttributes":
         """Export the hosted zone."""
         return jsii.invoke(self, "export", [])
 
@@ -1213,21 +1227,32 @@ class HostedZone(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-
 
         jsii.create(HostedZone, self, [scope, id, props])
 
-    @jsii.member(jsii_name="import")
+    @jsii.member(jsii_name="fromHostedZoneAttributes")
     @classmethod
-    def import_(cls, scope: aws_cdk.cdk.Construct, id: str, *, hosted_zone_id: str, zone_name: str) -> "IHostedZone":
+    def from_hosted_zone_attributes(cls, scope: aws_cdk.cdk.Construct, id: str, *, hosted_zone_id: str, zone_name: str) -> "IHostedZone":
         """Imports a hosted zone from another stack.
 
         Arguments:
             scope: -
             id: -
-            props: -
+            attrs: -
             hostedZoneId: Identifier of the hosted zone.
             zoneName: Name of the hosted zone.
         """
-        props: HostedZoneImportProps = {"hostedZoneId": hosted_zone_id, "zoneName": zone_name}
+        attrs: HostedZoneAttributes = {"hostedZoneId": hosted_zone_id, "zoneName": zone_name}
 
-        return jsii.sinvoke(cls, "import", [scope, id, props])
+        return jsii.sinvoke(cls, "fromHostedZoneAttributes", [scope, id, attrs])
+
+    @jsii.member(jsii_name="fromHostedZoneId")
+    @classmethod
+    def from_hosted_zone_id(cls, scope: aws_cdk.cdk.Construct, id: str, hosted_zone_id: str) -> "IHostedZone":
+        """
+        Arguments:
+            scope: -
+            id: -
+            hostedZoneId: -
+        """
+        return jsii.sinvoke(cls, "fromHostedZoneId", [scope, id, hosted_zone_id])
 
     @jsii.member(jsii_name="addVpc")
     def add_vpc(self, vpc: aws_cdk.aws_ec2.IVpcNetwork) -> None:
@@ -1239,7 +1264,7 @@ class HostedZone(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-
         return jsii.invoke(self, "addVpc", [vpc])
 
     @jsii.member(jsii_name="export")
-    def export(self) -> "HostedZoneImportProps":
+    def export(self) -> "HostedZoneAttributes":
         """Export the hosted zone."""
         return jsii.invoke(self, "export", [])
 
@@ -1271,11 +1296,39 @@ class HostedZone(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-
         return jsii.get(self, "hostedZoneNameServers")
 
 
+@jsii.interface(jsii_type="@aws-cdk/aws-route53.IPrivateHostedZone")
+class IPrivateHostedZone(IHostedZone, jsii.compat.Protocol):
+    @staticmethod
+    def __jsii_proxy_class__():
+        return _IPrivateHostedZoneProxy
+
+    pass
+
+class _IPrivateHostedZoneProxy(jsii.proxy_for(IHostedZone)):
+    __jsii_type__ = "@aws-cdk/aws-route53.IPrivateHostedZone"
+    pass
+
+@jsii.interface(jsii_type="@aws-cdk/aws-route53.IPublicHostedZone")
+class IPublicHostedZone(IHostedZone, jsii.compat.Protocol):
+    @staticmethod
+    def __jsii_proxy_class__():
+        return _IPublicHostedZoneProxy
+
+    pass
+
+class _IPublicHostedZoneProxy(jsii.proxy_for(IHostedZone)):
+    __jsii_type__ = "@aws-cdk/aws-route53.IPublicHostedZone"
+    pass
+
+@jsii.implements(IPrivateHostedZone)
 class PrivateHostedZone(HostedZone, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53.PrivateHostedZone"):
     """Create a Route53 private hosted zone for use in one or more VPCs.
 
     Note that ``enableDnsHostnames`` and ``enableDnsSupport`` must have been enabled
     for the VPC you're configuring for private hosted zones.
+
+    resource:
+        AWS::Route53::HostedZone
     """
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, vpc: aws_cdk.aws_ec2.IVpcNetwork, zone_name: str, comment: typing.Optional[str]=None, query_logs_log_group_arn: typing.Optional[str]=None) -> None:
         """
@@ -1298,6 +1351,17 @@ class PrivateHostedZone(HostedZone, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk
 
         jsii.create(PrivateHostedZone, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromPrivateHostedZoneId")
+    @classmethod
+    def from_private_hosted_zone_id(cls, scope: aws_cdk.cdk.Construct, id: str, private_hosted_zone_id: str) -> "IPrivateHostedZone":
+        """
+        Arguments:
+            scope: -
+            id: -
+            privateHostedZoneId: -
+        """
+        return jsii.sinvoke(cls, "fromPrivateHostedZoneId", [scope, id, private_hosted_zone_id])
+
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-route53.PrivateHostedZoneProps", jsii_struct_bases=[CommonHostedZoneProps])
 class PrivateHostedZoneProps(CommonHostedZoneProps, jsii.compat.TypedDict):
@@ -1308,8 +1372,13 @@ class PrivateHostedZoneProps(CommonHostedZoneProps, jsii.compat.TypedDict):
     associated additional VPCs using ``addVpc(vpc)``.
     """
 
+@jsii.implements(IPublicHostedZone)
 class PublicHostedZone(HostedZone, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-route53.PublicHostedZone"):
-    """Create a Route53 public hosted zone."""
+    """Create a Route53 public hosted zone.
+
+    resource:
+        AWS::Route53::HostedZone
+    """
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, zone_name: str, comment: typing.Optional[str]=None, query_logs_log_group_arn: typing.Optional[str]=None) -> None:
         """
         Arguments:
@@ -1330,6 +1399,17 @@ class PublicHostedZone(HostedZone, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/
 
         jsii.create(PublicHostedZone, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromPublicHostedZoneId")
+    @classmethod
+    def from_public_hosted_zone_id(cls, scope: aws_cdk.cdk.Construct, id: str, public_hosted_zone_id: str) -> "IPublicHostedZone":
+        """
+        Arguments:
+            scope: -
+            id: -
+            publicHostedZoneId: -
+        """
+        return jsii.sinvoke(cls, "fromPublicHostedZoneId", [scope, id, public_hosted_zone_id])
+
     @jsii.member(jsii_name="addDelegation")
     def add_delegation(self, delegate: "PublicHostedZone", *, comment: typing.Optional[str]=None, ttl: typing.Optional[jsii.Number]=None) -> None:
         """Adds a delegation from this zone to a designated zone.
@@ -1458,6 +1538,6 @@ class ZoneDelegationRecordProps(ZoneDelegationOptions, jsii.compat.TypedDict):
     zone: "IHostedZone"
     """The zone in which this delegate is defined."""
 
-__all__ = ["AliasRecord", "AliasRecordProps", "AliasRecordTargetProps", "CfnHealthCheck", "CfnHealthCheckProps", "CfnHostedZone", "CfnHostedZoneProps", "CfnRecordSet", "CfnRecordSetGroup", "CfnRecordSetGroupProps", "CfnRecordSetProps", "CnameRecord", "CnameRecordProps", "CommonHostedZoneProps", "HostedZone", "HostedZoneImportProps", "HostedZoneProps", "HostedZoneProvider", "HostedZoneProviderProps", "IAliasRecordTarget", "IHostedZone", "PrivateHostedZone", "PrivateHostedZoneProps", "PublicHostedZone", "PublicHostedZoneProps", "TxtRecord", "TxtRecordProps", "ZoneDelegationOptions", "ZoneDelegationRecord", "ZoneDelegationRecordProps", "__jsii_assembly__"]
+__all__ = ["AliasRecord", "AliasRecordProps", "AliasRecordTargetProps", "CfnHealthCheck", "CfnHealthCheckProps", "CfnHostedZone", "CfnHostedZoneProps", "CfnRecordSet", "CfnRecordSetGroup", "CfnRecordSetGroupProps", "CfnRecordSetProps", "CnameRecord", "CnameRecordProps", "CommonHostedZoneProps", "HostedZone", "HostedZoneAttributes", "HostedZoneProps", "HostedZoneProvider", "HostedZoneProviderProps", "IAliasRecordTarget", "IHostedZone", "IPrivateHostedZone", "IPublicHostedZone", "PrivateHostedZone", "PrivateHostedZoneProps", "PublicHostedZone", "PublicHostedZoneProps", "TxtRecord", "TxtRecordProps", "ZoneDelegationOptions", "ZoneDelegationRecord", "ZoneDelegationRecordProps", "__jsii_assembly__"]
 
 publication.publish()
